package lcsb.mapviewer.api.comment;

import java.awt.geom.Point2D;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import lcsb.mapviewer.api.BaseController;
import lcsb.mapviewer.api.QueryException;
import lcsb.mapviewer.services.SecurityException;

@RestController
@RequestMapping("/comment")
public class CommentController extends BaseController {

	@Autowired
	private CommentRestImpl commentController;

	@RequestMapping(value = "/getCommentList", method = { RequestMethod.GET, RequestMethod.POST }, produces = { MediaType.APPLICATION_JSON_VALUE })
	public List<Map<String, Object>> getOverlayList(@RequestParam(value = "token") String token, @RequestParam(value = "projectId") String projectId,
			@RequestParam(value = "columns", defaultValue = "") String columns, @RequestParam(value = "elementId", defaultValue = "") String elementId,
			@RequestParam(value = "elementType", defaultValue = "") String elementType, @RequestParam(value = "removed", defaultValue = "") String removed)
			throws SecurityException, QueryException {
		return commentController.getCommentList(token, projectId, columns, elementId, elementType, removed);
	}

	@RequestMapping(value = "/addComment", method = { RequestMethod.GET, RequestMethod.POST }, produces = { MediaType.APPLICATION_JSON_VALUE })
	public Map<String, Object> addComment(@RequestParam(value = "token") String token, @RequestParam(value = "projectId") String projectId,
			@RequestParam(value = "elementType", defaultValue = "POINT") String elementType, @RequestParam(value = "elementId", defaultValue = "") String elementId,
			@RequestParam(value = "name") String name, @RequestParam(value = "email") String email, @RequestParam(value = "content") String content,
			@RequestParam(value = "pinned", defaultValue = "true") String pinned, @RequestParam(value = "coordinates") String coordinates,
			@RequestParam(value = "modelId") String modelId) throws SecurityException, QueryException {
		String[] tmp = coordinates.split(",");
		if (tmp.length != 2) {
			throw new QueryException("Coordinates must be in the format: 'xxx.xx,yyy.yy'");
		}
		Double x = null;
		Double y = null;
		try {
			x = Double.valueOf(tmp[0]);
			y = Double.valueOf(tmp[1]);
		} catch (NumberFormatException e) {
			throw new QueryException("Coordinates must be in the format: 'xxx.xx,yyy.yy'", e);
		}
		Point2D pointCoordinates = new Point2D.Double(x, y);
		return commentController
				.addComment(token, projectId, elementType, elementId, name, email, content, pinned.toLowerCase().equals("true"), pointCoordinates, modelId);
	}

	/**
	 * @return the overlayController
	 * @see #commentController
	 */
	public CommentRestImpl getOverlayController() {
		return commentController;
	}

	/**
	 * @param overlayController
	 *          the overlayController to set
	 * @see #commentController
	 */
	public void setOverlayController(CommentRestImpl overlayController) {
		this.commentController = overlayController;
	}

}